@@ -22,9 +22,11 @@
 #include <fcntl.h>
 #include <arpa/inet.h>
 #include <netdb.h>
+#include <limits.h>
 
 #include <openct/logging.h>
 #include <openct/socket.h>
+#include <openct/path.h>
 #include <openct/error.h>
 
 static unsigned int ifd_xid = 1;
@@ -238,18 +240,18 @@ int ct_socket_connect(ct_socket_t * sock, const char *addr)
 /*
  * Listen on a socket
  */
-int ct_socket_listen(ct_socket_t * sock, const char *addr, int mode)
+int ct_socket_listen(ct_socket_t * sock, const char *path, int mode)
 {
 	ct_socket_close(sock);
-	if (ct_socket_make(sock, CT_MAKESOCK_BIND, addr) < 0)
+	if (ct_socket_make(sock, CT_MAKESOCK_BIND, path) < 0)
 		return -1;
 
 	if (listen(sock->fd, 5) < 0) {
 		ct_socket_close(sock);
 		return -1;
 	}
-	if (addr[0] == '/')
-		chmod(addr, mode);
+	if (path[0] == '/')
+		chmod(path, mode);
 
 	sock->listener = 1;
 	sock->events = POLLIN;
@@ -530,7 +532,11 @@ int ct_socket_filbuf(ct_socket_t * sock, long timeout)
 			return IFD_ERROR_TIMEOUT;
 	}
 
+retry:	
 	n = read(sock->fd, ct_buf_tail(bp), count);
+	if (n < 0 && errno == EINTR)
+		goto retry;
+
 	if (n < 0) {
 		ct_error("socket recv error: %m");
 		return -1;
@@ -786,12 +792,17 @@ int ct_socket_read(ct_socket_t * sock, void *ptr, size_t size)
  */
 void ct_socket_link(ct_socket_t * prev, ct_socket_t * sock)
 {
-	ct_socket_t *next = prev->next;
+	ct_socket_t *next;
+
+	if (!prev)
+		return;
+
+	next = prev->next;
 
 	if (next)
 		next->prev = sock;
-	if (prev)
-		prev->next = sock;
+
+	prev->next = sock;
 	sock->prev = prev;
 	sock->next = next;
 }
