@@ -19,7 +19,9 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <time.h>
+#include <limits.h>
 
+#include <openct/path.h>
 #include <openct/ifd.h>
 #include <openct/conf.h>
 #include <openct/logging.h>
@@ -33,7 +35,7 @@ static int opt_debug = 0;
 static int opt_hotplug = 0;
 static int opt_foreground = 0;
 static int opt_info = 0;
-static unsigned int opt_reader = -1;
+static const char *opt_reader = NULL;
 
 static void usage(int exval);
 static void version(void);
@@ -70,7 +72,7 @@ int main(int argc, char **argv)
 			opt_info = 1;
 			break;
 		case 'r':
-			opt_reader = atoi(optarg);
+			opt_reader = optarg;
 			break;
 		case 's':
 			ct_log_destination("@syslog");
@@ -102,17 +104,24 @@ int main(int argc, char **argv)
 	ct_config.debug = opt_debug;
 
 	/* Initialize IFD library */
-	if (ifd_init()) 
+	if (ifd_init())
 		return 1;
 
 	/* Allocate a socket slot
 	 * FIXME: may need to use a lock file here to
 	 * prevent race condition
 	 */
-	status = ct_status_alloc_slot(&opt_reader);
-	if (status == NULL) {
-		ct_error("too many readers, no reader slot available");
-		return 1;
+	{
+		int r = -1;
+		char path[PATH_MAX];
+
+		status = ct_status_alloc_slot(&r);
+		if (status == NULL) {
+			ct_error("too many readers, no reader slot available");
+			return 1;
+		}
+		snprintf(path,PATH_MAX,"%d",r);
+		opt_reader=strdup(path);
 	}
 
 	/* Become a daemon if needed - we do this after allocating the
@@ -162,14 +171,25 @@ int main(int argc, char **argv)
 	return 0;
 }
 
+static void TERMhandler(int signo)
+{
+	ct_mainloop_leave();
+}
+
 /*
  * Spawn a new ifd handler thread
  */
 void ifdhandler_run(ifd_reader_t * reader)
 {
-	char socket_name[1024];
 	ct_socket_t *sock;
 	int rc;
+	struct sigaction act;
+        char path[PATH_MAX];
+
+        if (! ct_format_path(path, PATH_MAX, opt_reader)) {
+		ct_error("ct_format_path failed!");
+		exit(1);
+	}
 
 	/* Activate reader */
 	if ((rc = ifd_activate(reader)) < 0) {
@@ -178,14 +198,7 @@ void ifdhandler_run(ifd_reader_t * reader)
 	}
 
 	sock = ct_socket_new(0);
-#if defined (sunray)
-	snprintf(socket_name, sizeof(socket_name),
-		 "%s/openct/%u", getenv("UTDEVROOT"), opt_reader);
-#else
-	snprintf(socket_name, sizeof(socket_name),
-		 "%s/%u", OPENCT_SOCKET_PATH, opt_reader);
-#endif
-	if (ct_socket_listen(sock, socket_name, 0666) < 0) {
+	if (ct_socket_listen(sock, path, 0666) < 0) {
 		ct_error("Failed to create server socket");
 		exit(1);
 	}
@@ -194,6 +207,12 @@ void ifdhandler_run(ifd_reader_t * reader)
 	sock->recv = ifdhandler_accept;
 	ct_mainloop_add_socket(sock);
 
+	/* Set an TERM signal handler for clean exit */
+	act.sa_handler = TERMhandler;
+	sigemptyset(&act.sa_mask);
+	act.sa_flags = 0;
+	sigaction(SIGTERM, &act, NULL);
+
 	/* Encapsulate the reader into a socket struct */
 	sock = ct_socket_new(0);
 	sock->fd = 0x7FFFFFFF;
@@ -203,6 +222,12 @@ void ifdhandler_run(ifd_reader_t * reader)
 
 	/* Call the server loop */
 	ct_mainloop();
+	ct_socket_unlink(sock);
+	ct_socket_free(sock);
+	memset(reader->status, 0, sizeof(*reader->status));
+	ct_status_update(reader->status);
+	ifd_debug(1, "ifdhandler for reader %s shut down", reader->name);
+
 	exit(0);
 }
 
