@@ -27,21 +27,20 @@
 #include "internal.h"
 #include "ria.h"
 
-static int	ria_devsock_process(ct_socket_t *, header_t *,
-				ct_buf_t *, ct_buf_t *);
-static void	ria_devsock_close(ct_socket_t *);
-static int	ria_poll_device(ct_socket_t *, struct pollfd *);
-static void	ria_close_device(ct_socket_t *);
+static int ria_devsock_process(ct_socket_t *, header_t *,
+			       ct_buf_t *, ct_buf_t *);
+static void ria_devsock_close(ct_socket_t *);
+static int ria_poll_device(ct_socket_t *, struct pollfd *);
+static void ria_close_device(ct_socket_t *);
 
 /*
  * Handle device side of things
  */
-ria_client_t *
-ria_export_device(const char *address, const char *device)
+ria_client_t *ria_export_device(const char *address, const char *device)
 {
-	ifd_device_t	*dev;
-	ria_client_t	*ria;
-	ct_socket_t	*sock;
+	ifd_device_t *dev;
+	ria_client_t *ria;
+	ct_socket_t *sock;
 
 	/* Open device */
 	if (!(dev = ifd_device_open(device))) {
@@ -77,11 +76,10 @@ ria_export_device(const char *address, const char *device)
 	return ria;
 }
 
-int
-ria_register_device(ria_client_t *ria, const char *name)
+int ria_register_device(ria_client_t * ria, const char *name)
 {
-	ifd_device_t	*dev = (ifd_device_t *) ria->user_data;
-	ria_device_t	devinfo;
+	ifd_device_t *dev = (ifd_device_t *) ria->user_data;
+	ria_device_t devinfo;
 
 	memset(&devinfo, 0, sizeof(devinfo));
 	strncpy(devinfo.name, name, RIA_NAME_MAX - 1);
@@ -93,17 +91,16 @@ ria_register_device(ria_client_t *ria, const char *name)
 		strcpy(devinfo.type, "other");
 
 	return ria_command(ria, RIA_MGR_REGISTER,
-			&devinfo, sizeof(devinfo), NULL, 0, -1);
+			   &devinfo, sizeof(devinfo), NULL, 0, -1);
 }
 
-int
-ria_devsock_process(ct_socket_t *sock, header_t *hdr,
-		ct_buf_t *args, ct_buf_t *resp)
+int ria_devsock_process(ct_socket_t * sock, header_t * hdr, ct_buf_t * args,
+			ct_buf_t * resp)
 {
-	ria_client_t	*ria = (ria_client_t *) sock->user_data;
-	ifd_device_t	*dev = (ifd_device_t *) ria->user_data;
-	unsigned char	cmd;
-	int		rc, count;
+	ria_client_t *ria = (ria_client_t *) sock->user_data;
+	ifd_device_t *dev = (ifd_device_t *) ria->user_data;
+	unsigned char cmd;
+	int rc, count;
 
 	ria_print_packet(sock, 2, "ria_devsock_process", hdr, args);
 
@@ -122,54 +119,54 @@ ria_devsock_process(ct_socket_t *sock, header_t *hdr,
 		return 0;
 	case RIA_SEND_BREAK:
 		{
-		unsigned int usec;
-		if ((rc = ct_buf_get(args, &usec, sizeof(usec))) < 0)
-                        return rc;
-                ifd_device_send_break(dev, ntohl(usec));
-                return 0;
+			unsigned int usec;
+			if ((rc = ct_buf_get(args, &usec, sizeof(usec))) < 0)
+				return rc;
+			ifd_device_send_break(dev, ntohl(usec));
+			return 0;
 		}
 	case RIA_SERIAL_GET_CONFIG:
 		{
-		ifd_device_params_t	parms;
-		ria_serial_conf_t	conf;
+			ifd_device_params_t parms;
+			ria_serial_conf_t conf;
 
-		if (dev->type != IFD_DEVICE_TYPE_SERIAL)
-			return IFD_ERROR_INCOMPATIBLE_DEVICE;
-		if ((rc = ifd_device_get_parameters(dev, &parms)) < 0)
-			return rc;
-		conf.speed	= htonl(parms.serial.speed);
-		conf.bits	= parms.serial.bits;
-		conf.stopbits	= parms.serial.stopbits;
-		conf.parity	= parms.serial.parity;
-		conf.check_parity= parms.serial.check_parity;
-		conf.rts	= parms.serial.rts;
-		conf.dtr	= parms.serial.dtr;
-		return ct_buf_put(resp, &conf, sizeof(conf));
-	    	}
+			if (dev->type != IFD_DEVICE_TYPE_SERIAL)
+				return IFD_ERROR_INCOMPATIBLE_DEVICE;
+			if ((rc = ifd_device_get_parameters(dev, &parms)) < 0)
+				return rc;
+			conf.speed = htonl(parms.serial.speed);
+			conf.bits = parms.serial.bits;
+			conf.stopbits = parms.serial.stopbits;
+			conf.parity = parms.serial.parity;
+			conf.check_parity = parms.serial.check_parity;
+			conf.rts = parms.serial.rts;
+			conf.dtr = parms.serial.dtr;
+			return ct_buf_put(resp, &conf, sizeof(conf));
+		}
 
 	case RIA_SERIAL_SET_CONFIG:
 		{
-		ifd_device_params_t	parms;
-		ria_serial_conf_t	conf;
+			ifd_device_params_t parms;
+			ria_serial_conf_t conf;
 
-		if (dev->type != IFD_DEVICE_TYPE_SERIAL)
-			return IFD_ERROR_INCOMPATIBLE_DEVICE;
-		if ((rc = ct_buf_get(args, &conf, sizeof(conf))) < 0)
-			return rc;
-		parms.serial.speed	= ntohl(conf.speed);
-		parms.serial.bits	= conf.bits;
-		parms.serial.stopbits	= conf.stopbits;
-		parms.serial.parity	= conf.parity;
-		parms.serial.check_parity= conf.check_parity;
-		parms.serial.rts	= conf.rts;
-		parms.serial.dtr	= conf.dtr;
-		if ((rc = ifd_device_set_parameters(dev, &parms)) < 0)
-			return rc;
-		return 0;
-	    	}
+			if (dev->type != IFD_DEVICE_TYPE_SERIAL)
+				return IFD_ERROR_INCOMPATIBLE_DEVICE;
+			if ((rc = ct_buf_get(args, &conf, sizeof(conf))) < 0)
+				return rc;
+			parms.serial.speed = ntohl(conf.speed);
+			parms.serial.bits = conf.bits;
+			parms.serial.stopbits = conf.stopbits;
+			parms.serial.parity = conf.parity;
+			parms.serial.check_parity = conf.check_parity;
+			parms.serial.rts = conf.rts;
+			parms.serial.dtr = conf.dtr;
+			if ((rc = ifd_device_set_parameters(dev, &parms)) < 0)
+				return rc;
+			return 0;
+		}
 
 	case RIA_DATA:
-		hdr->xid = 0; /* no reponse */
+		hdr->xid = 0;	/* no reponse */
 		count = ct_buf_avail(args);
 		rc = ct_buf_put(&ria->data, ct_buf_head(args), count);
 		if (rc < 0) {
@@ -178,7 +175,7 @@ ria_devsock_process(ct_socket_t *sock, header_t *hdr,
 		}
 		if (rc < 0)
 			ifd_debug(1, "unable to queue %u bytes for device",
-					count);
+				  count);
 		return 0;
 	default:
 		ct_error("Unexpected command 0x02%x\n", cmd);
@@ -187,20 +184,18 @@ ria_devsock_process(ct_socket_t *sock, header_t *hdr,
 
 }
 
-void
-ria_devsock_close(ct_socket_t *sock)
+void ria_devsock_close(ct_socket_t * sock)
 {
 	ct_error("Network connection closed, exiting\n");
 	exit(0);
 }
 
-static int
-ria_poll_device(ct_socket_t *sock, struct pollfd *pfd)
+static int ria_poll_device(ct_socket_t * sock, struct pollfd *pfd)
 {
-	unsigned char	buffer[512];
-	ria_client_t	*ria = (ria_client_t *) sock->user_data;
-	ifd_device_t	*dev = (ifd_device_t *) ria->user_data;
-	int		n, rc;
+	unsigned char buffer[512];
+	ria_client_t *ria = (ria_client_t *) sock->user_data;
+	ifd_device_t *dev = (ifd_device_t *) ria->user_data;
+	int n, rc;
 
 	pfd->fd = dev->fd;
 	if (pfd->revents & POLLIN) {
@@ -216,7 +211,7 @@ ria_poll_device(ct_socket_t *sock, struct pollfd *pfd)
 	}
 	if (pfd->revents & POLLOUT) {
 		n = write(dev->fd, ct_buf_head(&ria->data),
-				   ct_buf_avail(&ria->data));
+			  ct_buf_avail(&ria->data));
 		if (n < 0) {
 			ct_error("error writing to device: %m");
 			return -1;
@@ -235,14 +230,13 @@ ria_poll_device(ct_socket_t *sock, struct pollfd *pfd)
 	if (ct_buf_avail(&ria->data))
 		pfd->events |= POLLOUT;
 
-	if (1 /* hotplug */)
+	if (1 /* hotplug */ )
 		pfd->events |= POLLHUP;
 
 	return 1;
 }
 
-void
-ria_close_device(ct_socket_t *sock)
+void ria_close_device(ct_socket_t * sock)
 {
 	ct_error("Dispatcher requests that device is closed, abort");
 	exit(1);
