@@ -10,13 +10,13 @@
 #include "internal.h"
 #if defined (__linux__) && !defined (sunray)
 #include <sys/types.h>
-#include <linux/major.h>
-#include <linux/compiler.h>
-#include <linux/usbdevice_fs.h>
 #include <sys/sysmacros.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/poll.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/file.h>
 #include <string.h>
 #include <stdio.h>
 #include <signal.h>
@@ -24,11 +24,134 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <limits.h>
 #ifdef HAVE_LIBUSB
 #include <usb.h>
 #endif
 #include <openct/driver.h>
 
+/* imported from linux kernel header include/linux/usbdevice_fs.h */
+
+#define USBDEVICE_SUPER_MAGIC 0x9fa2
+
+/* usbdevfs ioctl codes */
+
+struct usbdevfs_ctrltransfer {
+	uint8_t bRequestType;
+	uint8_t bRequest;
+	uint16_t wValue;
+	uint16_t wIndex;
+	uint16_t wLength;
+	uint32_t timeout;  /* in milliseconds */
+ 	void *data;
+};
+
+struct usbdevfs_bulktransfer {
+	unsigned int ep;
+	unsigned int len;
+	unsigned int timeout; /* in milliseconds */
+	void *data;
+};
+
+struct usbdevfs_setinterface {
+	unsigned int interface;
+	unsigned int altsetting;
+};
+
+struct usbdevfs_disconnectsignal {
+	unsigned int signr;
+	void *context;
+};
+
+#define USBDEVFS_MAXDRIVERNAME 255
+
+struct usbdevfs_getdriver {
+	unsigned int interface;
+	char driver[USBDEVFS_MAXDRIVERNAME + 1];
+};
+
+struct usbdevfs_connectinfo {
+	unsigned int devnum;
+	unsigned char slow;
+};
+
+#define USBDEVFS_URB_SHORT_NOT_OK          1
+#define USBDEVFS_URB_ISO_ASAP              2
+
+#define USBDEVFS_URB_TYPE_ISO		   0
+#define USBDEVFS_URB_TYPE_INTERRUPT	   1
+#define USBDEVFS_URB_TYPE_CONTROL	   2
+#define USBDEVFS_URB_TYPE_BULK		   3
+
+struct usbdevfs_iso_packet_desc {
+	unsigned int length;
+	unsigned int actual_length;
+	unsigned int status;
+};
+
+struct usbdevfs_urb {
+	unsigned char type;
+	unsigned char endpoint;
+	int status;
+	unsigned int flags;
+	void *buffer;
+	int buffer_length;
+	int actual_length;
+	int start_frame;
+	int number_of_packets;
+	int error_count;
+	unsigned int signr;  /* signal to be sent on error, -1 if none should be sent */
+	void *usercontext;
+	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
+};
+
+/* ioctls for talking directly to drivers */
+struct usbdevfs_ioctl {
+	int	ifno;		/* interface 0..N ; negative numbers reserved */
+	int	ioctl_code;	/* MUST encode size + direction of data so the
+				 * macros in <asm/ioctl.h> give correct values */
+	void *data;	/* param buffer (in, or out) */
+};
+
+/* You can do most things with hubs just through control messages,
+ * except find out what device connects to what port. */
+struct usbdevfs_hub_portinfo {
+	char nports;		/* number of downstream ports in this hub */
+	char port [127];	/* e.g. port 3 connects to device 27 */
+};
+
+#define USBDEVFS_CONTROL           _IOWR('U', 0, struct usbdevfs_ctrltransfer)
+#define USBDEVFS_BULK              _IOWR('U', 2, struct usbdevfs_bulktransfer)
+#define USBDEVFS_RESETEP           _IOR('U', 3, unsigned int)
+#define USBDEVFS_SETINTERFACE      _IOR('U', 4, struct usbdevfs_setinterface)
+#define USBDEVFS_SETCONFIGURATION  _IOR('U', 5, unsigned int)
+#define USBDEVFS_GETDRIVER         _IOW('U', 8, struct usbdevfs_getdriver)
+#define USBDEVFS_SUBMITURB         _IOR('U', 10, struct usbdevfs_urb)
+#define USBDEVFS_DISCARDURB        _IO('U', 11)
+#define USBDEVFS_REAPURB           _IOW('U', 12, void *)
+#define USBDEVFS_REAPURBNDELAY     _IOW('U', 13, void *)
+#define USBDEVFS_DISCSIGNAL        _IOR('U', 14, struct usbdevfs_disconnectsignal)
+#define USBDEVFS_CLAIMINTERFACE    _IOR('U', 15, unsigned int)
+#define USBDEVFS_RELEASEINTERFACE  _IOR('U', 16, unsigned int)
+#define USBDEVFS_CONNECTINFO       _IOW('U', 17, struct usbdevfs_connectinfo)
+#define USBDEVFS_IOCTL             _IOWR('U', 18, struct usbdevfs_ioctl)
+#define USBDEVFS_HUB_PORTINFO      _IOR('U', 19, struct usbdevfs_hub_portinfo)
+#define USBDEVFS_RESET             _IO('U', 20)
+#define USBDEVFS_CLEAR_HALT        _IOR('U', 21, unsigned int)
+#define USBDEVFS_DISCONNECT        _IO('U', 22)
+#define USBDEVFS_CONNECT           _IO('U', 23)
+
+/* other constants from kernel code */
+
+#define TTY_MAJOR            4
+#define PTY_SLAVE_MAJOR              3
+#define UNIX98_PTY_MASTER_MAJOR      128
+#define UNIX98_PTY_SLAVE_MAJOR       (UNIX98_PTY_MASTER_MAJOR+UNIX98_PTY_MAJOR_COUNT)
+#define UNIX98_PTY_MAJOR_COUNT       8
+#define MISC_MAJOR           10
+
+/* end of import from usbdevice_fs.h */
+
 int ifd_sysdep_device_type(const char *name)
 {
 	struct stat stb;
@@ -36,7 +159,8 @@ int ifd_sysdep_device_type(const char *name)
 	if (!name || name[0] != '/')
 		return -1;
 
-	if (!strncmp(name, "/proc/bus/usb", 13))
+	if (!strncmp(name, "/proc/bus/usb", 13) ||
+		!strncmp(name, "/dev/bus/usb", 12)) 
 		return IFD_DEVICE_TYPE_USB;
 
 	if (stat(name, &stb) < 0)
@@ -83,7 +207,6 @@ int ifd_sysdep_usb_control(ifd_device_t * dev, unsigned int requesttype,
 	struct usbdevfs_ctrltransfer ctrl;
 	int rc;
 
-#ifdef LINUX_NEWUSB
 	ctrl.bRequestType = requesttype;
 	ctrl.bRequest = request;
 	ctrl.wValue = value;
@@ -91,15 +214,6 @@ int ifd_sysdep_usb_control(ifd_device_t * dev, unsigned int requesttype,
 	ctrl.wLength = len;
 	ctrl.data = data;
 	ctrl.timeout = timeout;
-#else
-	ctrl.requesttype = requesttype;
-	ctrl.request = request;
-	ctrl.value = value;
-	ctrl.index = index;
-	ctrl.length = len;
-	ctrl.data = data;
-	ctrl.timeout = timeout;
-#endif
 
 	if ((rc = ioctl(dev->fd, USBDEVFS_CONTROL, &ctrl)) < 0) {
 		ct_error("usb_control failed: %m");
@@ -292,9 +406,9 @@ int ifd_sysdep_usb_end_capture(ifd_device_t * dev, ifd_usb_capture_t * cap)
 	return rc;
 }
 
-int ifd_sysdep_usb_open(const char *device, int flags)
+int ifd_sysdep_usb_open(const char *device)
 {
-	return open(device, O_EXCL | O_RDWR);
+        return open(device, O_RDWR);
 }
 
 /*
@@ -317,6 +431,7 @@ int ifd_scan_usb(void)
 		for (dev = bus->devices; dev; dev = dev->next) {
 			const char *driver;
 			char device[PATH_MAX];
+			struct stat buf;
 
 			id.val[0] = dev->descriptor.idVendor;
 			id.val[1] = dev->descriptor.idProduct;
@@ -325,10 +440,17 @@ int ifd_scan_usb(void)
 				continue;
 
 			snprintf(device, sizeof(device),
-				 "/proc/bus/usb/%s/%s",
+				 "/dev/bus/usb/%s/%s",
 				 bus->dirname, dev->filename);
-
-			ifd_spawn_handler(driver, device, -1);
+			if (stat(device, &buf) == 0) {
+				ifd_spawn_handler(driver, device, -1);
+			} else {
+				snprintf(device, sizeof(device),
+				 	"/proc/bus/usb/%s/%s",
+				 	bus->dirname, dev->filename);
+			
+				ifd_spawn_handler(driver, device, -1);
+			}
 		}
 	}
 #endif
