@@ -9,6 +9,7 @@
 #if defined (sun) && !defined (sunray)
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/file.h>
 #include <dirent.h>
 #include <errno.h>
 #include <stdio.h>
@@ -84,7 +85,7 @@ static int open_devstat(char *name)
 	if (!devstat_fd) {
 		char *devstat;
 
-		if ((devstat = calloc(1,strlen(name) + 2)) == NULL) {
+		if ((devstat = calloc(1, strlen(name) + 2)) == NULL) {
 			ct_error("out of memory");
 			return IFD_ERROR_NO_MEMORY;
 		}
@@ -172,7 +173,7 @@ int open_ep(char *name, int interface, int endpoint, int direction, int flags)
 #if 0
 	strcat((char *)&filename, "stat");
 	if ((interfaces[interface][endpoint].ep_stat_fd[direction] =
-	     open(filename, O_RDONLY | O_EXCL | O_NONBLOCK)) < 0) {
+	     open(filename, O_RDONLY | O_NONBLOCK)) < 0) {
 		ifd_debug(6, "open_ep: error opening \"%s\": %s", filename,
 			  strerror(errno));
 		close(interfaces[interface][endpoint].ep_fd[direction]);
@@ -184,6 +185,7 @@ int open_ep(char *name, int interface, int endpoint, int direction, int flags)
 	return 0;
 }
 
+void
 close_ep(int interface, int endpoint, int direction)
 {
 	if (interfaces[interface][endpoint].ep_fd[direction]) {
@@ -303,11 +305,11 @@ ifd_sysdep_usb_control(ifd_device_t * dev,
 
 	bytes_to_process = USB_REQUEST_SIZE +
 	    ((requesttype & USB_EP_DIR_MASK) == USB_EP_DIR_OUT ? len : 0);
-	if ((usb_control_req = calloc(1,bytes_to_process)) == NULL) {
+	if ((usb_control_req = calloc(1, bytes_to_process)) == NULL) {
 		ct_error("out of memory");
 		return -1;
 	}
-	if ((recv_data = calloc(1,len)) == NULL) {
+	if ((recv_data = calloc(1, len)) == NULL) {
 		ct_error("out of memory");
 		free(usb_control_req);
 		return -1;
@@ -527,9 +529,9 @@ int ifd_sysdep_usb_end_capture(ifd_device_t * dev, ifd_usb_capture_t * cap)
 	return 0;
 }
 
-int ifd_sysdep_usb_open(const char *device, int flags)
+int ifd_sysdep_usb_open(const char *device)
 {
-	return open(device, O_EXCL | O_RDWR);
+        return open(device, O_RDWR);
 }
 
 /*
